<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fi_FI">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../../gui/aboutdialog.cpp" line="27"/>
        <source>About</source>
        <translation>Tietoa</translation>
    </message>
</context>
<context>
    <name>CallListener</name>
    <message>
        <source>Searching...</source>
        <translation>Haetaan...</translation>
    </message>
    <message>
        <source>Request timed out</source>
        <translation>Pyyntö aikakatkaistiin</translation>
    </message>
    <message>
        <source>Searching failed:</source>
        <translation>Haku epäonnistui:</translation>
    </message>
    <message>
        <source>Phone number was not found</source>
        <translation>Numeroa ei löytynyt</translation>
    </message>
    <message>
        <source>Automatic connecting is not allowed by settings.</source>
        <translation>Automaattista yhteyden muodostamista ei ole sallittu asetuksista.</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Yhdistetään...</translation>
    </message>
    <message>
        <source>No available 3G or WLAN networks found.</source>
        <translation>Käytettävissä olevia 3G- tai WLAN-verkkoja ei löytynyt.</translation>
    </message>
    <message>
        <source>Selected access point doesn&apos;t exist.</source>
        <translation>Valittua yhteysosoitetta ei löytynyt.</translation>
    </message>
    <message>
        <source>Unable to connect to network.</source>
        <translation>Yhteyden muodostaminen ei onnistunut.</translation>
    </message>
</context>
<context>
    <name>ConnectionSelector</name>
    <message>
        <location filename="../../gui/connectionselector.cpp" line="69"/>
        <source>Use global setting</source>
        <translation>Käytä järj. asetusta</translation>
    </message>
    <message>
        <location filename="../../gui/connectionselector.cpp" line="70"/>
        <source>WLAN connection</source>
        <translation>WLAN-yhteys</translation>
    </message>
    <message>
        <location filename="../../gui/connectionselector.cpp" line="71"/>
        <source>GPRS connection</source>
        <translation>GPRS-yhteys</translation>
    </message>
    <message>
        <location filename="../../gui/connectionselector.cpp" line="72"/>
        <source>Any connection</source>
        <translation>Mikä tahansa yhteys</translation>
    </message>
</context>
<context>
    <name>DetailWindow</name>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="42"/>
        <location filename="../../gui/detailwindow.cpp" line="119"/>
        <source>Add to contacts</source>
        <translation>Lisää yhteistietoihin</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="43"/>
        <source>Copy number to clipboard</source>
        <translation>Kopioi numero leikepöydälle</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="44"/>
        <source>Call</source>
        <translation>Soita</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="45"/>
        <source>Send SMS</source>
        <translation>Lähetä SMS</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="53"/>
        <location filename="../../gui/detailwindow.cpp" line="122"/>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="54"/>
        <source>Street</source>
        <translation>Katu</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="55"/>
        <source>City</source>
        <translation>Kaupunki</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="57"/>
        <source>Phone number</source>
        <translation>Puhelinnumero</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="109"/>
        <source>Unable make call</source>
        <translation>Puhelun aloittaminen epäonnistui</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="123"/>
        <source>Add</source>
        <translation>Lisää</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="156"/>
        <source>Contact was successfully added to contacts.</source>
        <translation>Yhteystieto lisättiin onnistuneesti.</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="194"/>
        <source>Unable to open SMS application</source>
        <translation>SMS-sovelluksen käynnistäminen epäonnistui</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="109"/>
        <location filename="../../gui/detailwindow.cpp" line="160"/>
        <location filename="../../gui/detailwindow.cpp" line="194"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="160"/>
        <source>Unable to add contact.</source>
        <translation>Yhteystiedon lisääminen epäonnistui,</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="170"/>
        <source>Number was successfully copied to clipboard.</source>
        <translation>Numero kopioitiin onnistuneesti leikepöydälle.</translation>
    </message>
</context>
<context>
    <name>EmptyGuiConfig</name>
    <message>
        <location filename="../../gui/emptyguiconfig.cpp" line="27"/>
        <source>Selected phonebook has no settings to configure.</source>
        <translation>Valitussa puhelinluettelossa ei ole muokattavia asetuksia.</translation>
    </message>
</context>
<context>
    <name>EniroGuiConfig</name>
    <message>
        <location filename="../../gui/eniroguiconfig.cpp" line="36"/>
        <source>Eniro username</source>
        <translation>Eniro-tunnus</translation>
    </message>
    <message>
        <location filename="../../gui/eniroguiconfig.cpp" line="39"/>
        <source>Eniro password</source>
        <translation>Eniro-salasana</translation>
    </message>
    <message>
        <location filename="../../gui/eniroguiconfig.cpp" line="45"/>
        <source>Eniro site</source>
        <translation>Eniro-sivusto</translation>
    </message>
    <message>
        <location filename="../../gui/eniroguiconfig.cpp" line="57"/>
        <source>Finnish</source>
        <translation>Suomi</translation>
    </message>
    <message>
        <location filename="../../gui/eniroguiconfig.cpp" line="60"/>
        <source>Swedish</source>
        <translation>Ruotsi</translation>
    </message>
    <message>
        <location filename="../../gui/eniroguiconfig.cpp" line="63"/>
        <source>Danish</source>
        <translation>Tanska</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="48"/>
        <source>Jenirok</source>
        <translation>Jenirok</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="54"/>
        <location filename="../../gui/mainwindow.cpp" line="151"/>
        <source>Stop daemon</source>
        <translation>Pysäytä</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="60"/>
        <location filename="../../gui/mainwindow.cpp" line="117"/>
        <source>Start daemon</source>
        <translation>Käynnistä</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="65"/>
        <source>Search</source>
        <translation>Hae</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="82"/>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="83"/>
        <source>About</source>
        <translation>Tietoa</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="115"/>
        <source>Daemon was successfully stopped.</source>
        <translation>Palvelu pysäytettiin onnistuneesti.</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="116"/>
        <source>Unable to stop daemon.</source>
        <translation>Palvelun pysäyttäminen ei onnistunut.</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="127"/>
        <source>Unable to start daemon</source>
        <translation>Palvelun käynnistäminen ei onnistunut</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="129"/>
        <source>Daemon cannot be started because it&apos;s not allowed to connect to the Internet. You have to either allow automatic Internet connection in Jenirok settings or in global Maemo settings.</source>
        <translation>Palvelua ei voida käynnistää, koska sillä ei ole oikeutta yhdistää Internetiin. Sinun täytyy sallia automaattinen yhteyden muodostaminen joko Jenirokin asetuksista tai Maemon omista Internet-asetuksista.</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="133"/>
        <source>Open settings</source>
        <translation>Avaa asetukset</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="135"/>
        <source>Close</source>
        <translation>Sulje</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="149"/>
        <source>Daemon was successfully started.</source>
        <translation>Palvelu käynnistettiin onnistuneesti.</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="150"/>
        <source>Unable to start daemon.</source>
        <translation>Palvelun käynnistäminen ei onnistunut.</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="157"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="181"/>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="181"/>
        <source>You need to set login details or other options in settings before using this feature.</source>
        <translation>Sinun täytyy asettaa kirjautumistiedot tai muita asetuksia ennen kuin voit käyttää tätä ominaisuutta.</translation>
    </message>
</context>
<context>
    <name>ResultWindow</name>
    <message>
        <location filename="../../gui/resultwindow.cpp" line="36"/>
        <source>Search results</source>
        <translation>Hakutulokset</translation>
    </message>
    <message>
        <location filename="../../gui/resultwindow.cpp" line="163"/>
        <source>Connection to server failed</source>
        <translation>Palvelimelle yhdistäminen epäonnistui</translation>
    </message>
    <message>
        <location filename="../../gui/resultwindow.cpp" line="166"/>
        <source>Invalid login details</source>
        <translation>Virheellinen tunnus tai salasana</translation>
    </message>
    <message>
        <location filename="../../gui/resultwindow.cpp" line="169"/>
        <source>Request timed out</source>
        <translation>Pyyntö aikakatkaistiin</translation>
    </message>
    <message>
        <location filename="../../gui/resultwindow.cpp" line="172"/>
        <source>Searching failed:</source>
        <translation>Haku epäonnistui:</translation>
    </message>
    <message>
        <location filename="../../gui/resultwindow.cpp" line="176"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location filename="../../gui/resultwindow.cpp" line="181"/>
        <source>No results found</source>
        <translation>Ei hakutuloksia</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <location filename="../../gui/searchdialog.cpp" line="30"/>
        <location filename="../../gui/searchdialog.cpp" line="55"/>
        <source>Search</source>
        <translation>Hae</translation>
    </message>
    <message>
        <location filename="../../gui/searchdialog.cpp" line="33"/>
        <source>Name/number</source>
        <translation>Numero/nimi</translation>
    </message>
    <message>
        <location filename="../../gui/searchdialog.cpp" line="39"/>
        <source>Location</source>
        <translation>Sijainti</translation>
    </message>
    <message>
        <location filename="../../gui/searchdialog.cpp" line="44"/>
        <source>Type</source>
        <translation>Tyyppi</translation>
    </message>
    <message>
        <location filename="../../gui/searchdialog.cpp" line="45"/>
        <source>Persons</source>
        <translation>Henkilöt</translation>
    </message>
    <message>
        <location filename="../../gui/searchdialog.cpp" line="46"/>
        <source>Companies</source>
        <translation>Yritykset</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../settings.cpp" line="168"/>
        <source>fi</source>
        <translation>fi</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="44"/>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="58"/>
        <source>Cache size (numbers)</source>
        <translation>Välimuistin koko (numeroa)</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="61"/>
        <source>Clear</source>
        <translation>Tyhjennä</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="64"/>
        <source>Language</source>
        <translation>Kieli</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="65"/>
        <source>Automatic</source>
        <translation>Automaattinen</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="82"/>
        <source>Phonebook</source>
        <translation>Puhelinluettelo</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="102"/>
        <source>Autostart</source>
        <translation>Käynnistä automaattisesti</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="104"/>
        <source>Enabled</source>
        <translation>Kyllä</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="105"/>
        <source>Disabled</source>
        <translation>Ei</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="108"/>
        <source>Connect automatically on</source>
        <translation>Yhdistä automaattisesti</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="112"/>
        <source>Save</source>
        <translation>Tallenna</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="137"/>
        <source>General</source>
        <translation>Yleiset</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="138"/>
        <source>Daemon</source>
        <translation>Taustaprosessi</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="139"/>
        <location filename="../../gui/settingsdialog.cpp" line="208"/>
        <source>Phonebook settings</source>
        <translation>Puhelinluettelo</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="170"/>
        <source>Restarting daemon...</source>
        <translation>Käynnistetään palvelu uudelleen...</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="176"/>
        <source>You need to restart Jenirok for language change to take effect.</source>
        <translation>Jenirok täytyy käynnistää uudelleen, jotta uudet kieliasetukset tulevat voimaan.</translation>
    </message>
    <message numerus="yes">
        <location filename="../../gui/settingsdialog.cpp" line="188"/>
        <source>%n number(s) were deleted from cache</source>
        <translation>
            <numerusform>Poistettiin %n numero välimuistista</numerusform>
            <numerusform>Poistettiin %n numeroa välimuistista</numerusform>
        </translation>
    </message>
</context>
</TS>
